@@ -69,6 +69,13 @@ class AddToPlaylistDialog(QDialog, Ui_AddToPlaylistDialog):
             item = QListWidgetItem(unicode(playlist.title.text, "utf-8"))
             item.setTextAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
             self.listWidget.addItem(item)
+            
+    def toggleBusy(self, isBusy):
+        """
+        Shows the progress indicator if argument is True, 
+        and hides it otherwise.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
     
     @pyqtSignature("QListWidgetItem*")
     def on_listWidget_itemClicked(self, item):
@@ -78,6 +85,7 @@ class AddToPlaylistDialog(QDialog, Ui_AddToPlaylistDialog):
         row = self.listWidget.row(item)
         playlist = self.yt.playlistFeed.entry[row]
         try:
+            self.toggleBusy(True)
             for video in self.videos:
                 if "playlists" in video.id.text:
                     videoId = video.comments.feed_link[0].href.split("/")[-2]
@@ -90,6 +98,7 @@ class AddToPlaylistDialog(QDialog, Ui_AddToPlaylistDialog):
                 QMaemo5InformationBox.information(self, "Your chosen videos have been added to your playlist: \'%s\'" % item.text())
         except:
             QMaemo5InformationBox.information(self, "Unable to add videos to your playlist")
+        self.toggleBusy(False)
         self.accept()
 
     @pyqtSignature("")
@@ -130,6 +139,13 @@ class NewPlaylistDialog(QDialog, Ui_NewPlaylistDialog):
             self.resize(800, 400)
             self.saveButton.setGeometry(QRect(640, 290, 150, 70))
             self.privateCheckBox.setGeometry(QRect(10, 290, 460, 70))
+    
+    def toggleBusy(self, isBusy):
+        """
+        Shows the progress indicator if argument is True, 
+        and hides it otherwise.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
  
     @pyqtSignature("")
     def on_saveButton_clicked(self):
@@ -141,18 +157,20 @@ class NewPlaylistDialog(QDialog, Ui_NewPlaylistDialog):
         playlistDescription = unicode(self.descriptionEdit.toPlainText())
         private = self.privateCheckBox.isChecked()
         try:
+            self.toggleBusy(True)
             playlist = youtubeservice.YouTubeDataService.newPlaylist(playlistTitle, playlistDescription, private)
             if self.videos == None:
-                QMaemo5InformationBox.information(self, "Your new playlist: \'%s\' has been created" % unicode(playlistTitle, "utf-8"))
+                QMaemo5InformationBox.information(self, "Your new playlist: \'%s\' has been created" % playlistTitle)
             else:
                 for video in self.videos:
                     youtubeservice.YouTubeDataService.addVideoToPlaylist(playlist, video.id.text)
                 if len(self.videos) == 1:
-                    QMaemo5InformationBox.information(self, "\'%s\' has been added to your playlist: \'%s\'" % (unicode(video.media.title.text, "utf-8"), unicode(playlistTitle, "utf-8")))
+                    QMaemo5InformationBox.information(self, "\'%s\' has been added to your playlist: \'%s\'" % (self.videos[0].media.title.text, playlistTitle))
                 else:
-                    QMaemo5InformationBox.information(self, "Your chosen videos have been added to your playlist: \'%s\'" % unicode(playlistTitle, "utf-8"))
+                    QMaemo5InformationBox.information(self, "Your chosen videos have been added to your playlist: \'%s\'" % playlistTitle)
         except:
             QMaemo5InformationBox.information(self, "Unable to create new playlist") 
+        self.toggleBusy(False)
         self.accept()   
 
 class EditPlaylistDialog(NewPlaylistDialog):
@@ -184,10 +202,12 @@ class EditPlaylistDialog(NewPlaylistDialog):
         private = self.privateCheckBox.isChecked()
         playlistId = self.playlist.id.text.split("/")[-1]
         try:
+            self.toggleBusy(True)
             youtubeservice.YouTubeDataService.updatePlaylist(playlistId, newPlaylistTitle, newPlaylistDescription, private)
             QMaemo5InformationBox.information(self, "Your playlist metadata has been updated")
         except:
             QMaemo5InformationBox.information(self, "Unable to update your playlist metadata") 
+        self.toggleBusy(False)
         self.accept()
 
 class EditVideoDialog(NewPlaylistDialog):
@@ -228,12 +248,13 @@ class EditVideoDialog(NewPlaylistDialog):
         newVideoTitle = unicode(self.titleEdit.text())
         newVideoDescription = unicode(self.descriptionEdit.toPlainText())
         try:
+            self.toggleBusy(True)
             youtubeservice.YouTubeDataService.updateVideo(self.video.id.text, newVideoTitle, newVideoDescription)
             QMaemo5InformationBox.information(self, "Your video metadata has been updated")
-            self.accept()
         except:
             QMaemo5InformationBox.information(self, "Unable to update your video metadata") 
-            self.close()
+        self.toggleBusy(False)
+        self.accept()
 
 class EditPlaylistVideoDialog(NewPlaylistDialog):
     """
@@ -296,12 +317,13 @@ class EditPlaylistVideoDialog(NewPlaylistDialog):
         newPosition = unicode(self.positionButton.valueText())
         playlistVideoId = self.playlistVideo.id.text.split("/")[-1]      
         try:
+            self.toggleBusy(True)
             youtubeservice.YouTubeDataService.updatePlaylistVideo(self.playlistId, playlistVideoId, newVideoTitle, newVideoDescription, newPosition)
             QMaemo5InformationBox.information(self, "Your custom metadata has been updated")
-            self.accept()      
         except:
             QMaemo5InformationBox.information(self, "Unable to update your custom metadata") 
-            self.close()      
+        self.toggleBusy(False)
+        self.accept()      
         
 
 class ConfirmDeleteDialog(QDialog, Ui_ConfirmDeleteDialog):
@@ -571,6 +593,10 @@ class SettingsDialog(QDialog):
         self.accountButton.setValueText(youtubeservice.YouTubeDataService.defaultUser)
         self.mediaPlayerModel = QStandardItemModel(0, 1)
         mediaPlayers = {"Media Player": "/usr/bin/mediaplayer", "KMPlayer": "/opt/kmplayer/bin/kmplayer", "MPlayer": "/usr/bin/mplayer"}
+        item = QStandardItem("cuteTube Player")
+        item.setEditable(False)
+        item.setTextAlignment(Qt.AlignCenter)
+        self.mediaPlayerModel.appendRow(item)
         for mediaPlayer in mediaPlayers.iterkeys():
             if os.path.exists(mediaPlayers.get(mediaPlayer)):
                 item = QStandardItem(mediaPlayer)
@@ -603,6 +629,9 @@ class SettingsDialog(QDialog):
         self.downloadFormatButton.setPickSelector(self.downloadFormatSelector)
         downloadFormat = youtubeservice.YouTubeVideoDownloader.downloadFormat
         self.downloadFormatSelector.setCurrentIndex(youtubeservice.YouTubeVideoPlayer.formatList.index(downloadFormat))
+        self.searchesLabel = QLabel("Youtube Searches")
+        self.searchesLabel.setStyleSheet("color: rgb(120, 120, 120)")
+        self.clearSearchesButton = QPushButton("Clear recent searches", self)
         self.scrollArea = QScrollArea(self)
         self.scrollArea.setMaximumHeight(460)
         self.scrollArea.setFixedWidth(620)
@@ -618,6 +647,8 @@ class SettingsDialog(QDialog):
         vBox.addWidget(self.downloadFolderButton)
         vBox.addWidget(self.downloadFormatButton)
         vBox.addWidget(self.downloadStatusCheckBox)
+        vBox.addWidget(self.searchesLabel)
+        vBox.addWidget(self.clearSearchesButton)
         self.scrollArea.setWidget(scrollWidget)
         vBox = QVBoxLayout(self)
         vBox.addWidget(self.scrollArea)
@@ -625,6 +656,7 @@ class SettingsDialog(QDialog):
         self.show()
         self.connect(self.saveButton,  SIGNAL("clicked()"),  self.saveSettings)
         self.connect(self.downloadFolderButton,  SIGNAL("clicked()"),  self.chooseDownloadFolder)
+        self.connect(self.clearSearchesButton, SIGNAL("clicked()"), self.clearRecentSearches)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         
     def orientationChanged(self):
@@ -635,12 +667,12 @@ class SettingsDialog(QDialog):
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
             self.resize(480,  720)
-            for button in (self.accountButton, self.mediaPlayerButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox):
+            for button in (self.accountButton, self.mediaPlayerButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton):
                 button.setFixedWidth(420)
             self.saveButton.setGeometry(QRect(10,  620,  460,  70))
         else:
             self.resize(800,  400)
-            for button in (self.accountButton, self.mediaPlayerButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox):
+            for button in (self.accountButton, self.mediaPlayerButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton):
                 button.setFixedWidth(580)
             self.saveButton.setGeometry(QRect(640,  300,  150,  70))
         
@@ -649,6 +681,17 @@ class SettingsDialog(QDialog):
         newFolder = QFileDialog.getExistingDirectory(self, directory = currentFolder, options = QFileDialog.ShowDirsOnly)
         if newFolder != "":
             self.downloadFolderButton.setValueText(newFolder)
+            
+    def clearRecentSearches(self):
+        """
+        Clears the user's recent searches.
+        """
+        try:
+            SearchDialog.recentSearches.clear()
+            QMaemo5InformationBox.information(self, "Your recent searches have been cleared")
+        except:
+            QMaemo5InformationBox.information(self, "Unable to clear your recent searches")
+        
 
     def saveSettings(self):
         """
