@@ -15,6 +15,7 @@ import videoinfowindow
 import customwidgets
 import youtubeservice
 import cutetubedialogs
+import videoplaybackwindow
 
 class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
     """
@@ -418,11 +419,14 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         Adds all checked videos to the user's favourites.
         """
         try:
-            for video in self.pencilList:
+            self.toggleBusy(True)
+            for row in self.pencilList:
+                video = self.yt.videoList[row]
                 youtubeservice.YouTubeDataService.addVideoToFavourites(video)
             QMaemo5InformationBox.information(self, "Your chosen videos have been added to your favourites")
         except:
             QMaemo5InformationBox.information(self, "Unable to add videos to your favourites")
+        self.toggleBusy(False)
         self.actionPencil.toggle()
 
     def queueChanged(self, queueLength):
@@ -717,12 +721,10 @@ class PlaylistsWindow(CutetubeWindows):
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("My Playlists")
         self.actionNewPlaylist.setVisible(True)
-#        self.actionPlayPlaylist2.setVisible(True)
         self.actionEditPlaylist.setVisible(True)
         self.actionDeletePlaylist.setVisible(True)
         self.connect(self.actionEditPlaylist, SIGNAL("triggered()"), self.editPlaylist)
-        self.connect(self.actionDeletePlaylist, SIGNAL("triggered()"), self.deletePlaylist)
-#        self.connect(self.actionPlayPlaylist2, SIGNAL("triggered()"), self.playPlaylist)
+        self.connect(self.actionDeletePlaylist, SIGNAL("triggered()"), self.deletePlaylist)        
         self.show()
         self.yt = youtubeservice.YouTubePlaylistFeed(self)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.loadPlaylists)
@@ -773,21 +775,6 @@ class PlaylistsWindow(CutetubeWindows):
             QMaemo5InformationBox.information(self, "Unable to delete your playlist")
         self.listWidget.setCurrentRow(-1)
         
-    def playPlaylist(self):
-        """
-        Plays the entire playlist passed to the 
-        media player.
-        """
-        youtubeservice.YouTubeVideoPlayer.playlist = self.yt.videoList
-        try:
-            self.ytPlayer = youtubeservice.YouTubeVideoPlayer(self)
-            self.ytPlayer.start()
-            QMaemo5InformationBox.information(self, "Playing your playlist: \'%s\'" % unicode(playlistTitle, "utf-8"))
-        except:
-            QMaemo5InformationBox.information(self, "Unable to play playlist")
-        self.listWidget.setCurrentRow(-1) 
-        self.closeFilter()
-        
     @pyqtSignature("QListWidgetItem*")
     def on_listWidget_itemClicked(self, item):
         """
@@ -839,7 +826,8 @@ class PlaylistVideosWindow(CutetubeWindows):
         CutetubeWindows.__init__(self, parent)
         self.playlistName = playlistName
         self.setWindowTitle(self.playlistName)
-#        self.actionPlayPlaylist.setVisible(True)
+        if youtubeservice.YouTubeVideoPlayer.mediaPlayer == "cuteTube Player":
+            self.actionPlayPlaylist.setVisible(True)
         self.actionSearch.setVisible(True)
         self.actionSearch.setText("Find more of \'%s\'" % self.playlistName)
         self.actionAddToQueue.setVisible(True)
@@ -943,11 +931,8 @@ class PlaylistVideosWindow(CutetubeWindows):
         Plays the entire playlist passed to the 
         media player.
         """
-        youtubeservice.YouTubeVideoPlayer.playlist = self.yt.videoList
         try:
-            self.ytPlayer = youtubeservice.YouTubeVideoPlayer(self)
-            self.ytPlayer.start()
-            QMaemo5InformationBox.information(self, "Playing your playlist: \'%s\'" % unicode(self.playlistName, "utf-8"))
+            videoPlaybackWindow = videoplaybackwindow.VideoPlaybackWindow(self, playlist = self.yt.videoList)
         except:
             QMaemo5InformationBox.information(self, "Unable to play playlist")
 
@@ -961,7 +946,7 @@ class PlaybackQueueWindow(CutetubeWindows):
         """
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("My Playback Queue")
-#        self.actionPlayQueue.setVisible(True)
+        self.actionPlayQueue.setVisible(True)
         self.actionClearQueue.setVisible(True)
         self.actionSaveQueue.setVisible(True)
         self.actionAddToFavourites.setVisible(True)
@@ -973,31 +958,7 @@ class PlaybackQueueWindow(CutetubeWindows):
         self.yt = youtubeservice.YouTubeQueueFeed(self)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.loadData()
-
-    def playVideo(self):
-        row = self.listWidget.currentRow()
-        video = youtubeservice.YouTubeVideoPlayer.playlist[row]
-        try:
-            self.ytPlayer = youtubeservice.YouTubeVideoPlayer(self, video)
-            self.ytPlayer.start()
-            QMaemo5InformationBox.information(self, "Playing \'%s\'" % unicode(videoTitle, "utf-8"))
-        except:
-            QMaemo5InformationBox.information(self, "Unable to play video")
-        self.listWidget.setCurrentRow(-1)
         
-    def downloadVideo(self):
-        row = self.listWidget.currentRow()
-        video = youtubeservice.YouTubeVideoPlayer.playlist[row]
-        videoTitle = video.media.title.text
-        try:
-            youtubeservice.YouTubeVideoDownloader.addTask(video)
-            QMaemo5InformationBox.information(self, "\'%s\' has been added to your download queue" % unicode(videoTitle, "utf-8"))
-            taskQueueLength = len(youtubeservice.YouTubeVideoDownloader.taskQueue)
-            self.downloadsChanged(taskQueueLength)
-        except:
-            QMaemo5InformationBox.information(self, "Unable to add video to your download queue")
-        self.listWidget.setCurrentRow(-1)
-
     @pyqtSignature("QListWidgetItem*")
     def on_listWidget_itemClicked(self, item):
         """
@@ -1053,6 +1014,17 @@ class PlaybackQueueWindow(CutetubeWindows):
         except:
             QMaemo5InformationBox.information(self, "Unable to remove video from your playback queue")
         self.listWidget.setCurrentRow(-1)
+        
+    @pyqtSignature("")
+    def on_actionPlayQueue_triggered(self):
+        """
+        Plays the full playback queue.
+        """
+        try:
+            playlist = youtubeservice.YouTubeVideoPlayer.playlist
+            videoPlaybackWindow = videoplaybackwindow.VideoPlaybackWindow(self, playlist = playlist)
+        except:
+            QMaemo5InformationBox.information(self, "Unable to play your playback queue")
 
     @pyqtSignature("")
     def on_actionClearQueue_triggered(self):
@@ -1211,13 +1183,26 @@ class DownloadsWindow(CutetubeWindows):
         self.actionRemoveFromQueue.setVisible(True)
         self.actionRemoveFromQueue.setText("Cancel Download")
         self.actionClearQueue.setVisible(True)
-        self.actionClearQueue.setText("Clear Download Queue")
+        self.actionClearQueue.setText("Clear Downloads")
         self.actionPauseDownload.setVisible(True)
         self.actionResumeDownload.setVisible(True)
         self.actionDownloads.setVisible(False)
         self.actionGoToQueue.setVisible(False)
         self.actionResumeDownloads.setVisible(True)
         self.actionPauseDownloads.setVisible(True)
+        self.filterGroup = QActionGroup(self)
+        self.filterGroup.setExclusive(True)
+        self.actionQueued = QAction("Current", self.filterGroup)
+        self.actionQueued.setCheckable(True)
+        self.actionQueued.setChecked(False)
+        self.actionAll = QAction("All", self.filterGroup)
+        self.actionAll.setCheckable(True)
+        self.actionAll.setChecked(True)
+        self.actionCompleted = QAction("Completed", self.filterGroup)
+        self.actionCompleted.setCheckable(True)
+        self.actionCompleted.setChecked(False)
+        self.menuMenu.addActions(self.filterGroup.actions())
+        self.connect(self.filterGroup, SIGNAL("selected(QAction*)"), self.filterDownloads)
         self.connect(self.actionRemoveFromQueue,  SIGNAL("triggered()"),  self.cancelDownload)
         self.connect(self.actionPauseDownload,  SIGNAL("triggered()"),  self.pauseDownload)
         self.connect(self.actionResumeDownload,  SIGNAL("triggered()"),  self.resumeDownload)
@@ -1228,6 +1213,46 @@ class DownloadsWindow(CutetubeWindows):
         for task in youtubeservice.YouTubeVideoDownloader.taskQueue:
             self.connect(task, SIGNAL("downloadUpdated()"), self.updateDownloadStatus)
             self.connect(task, SIGNAL("statusChanged()"), self.updateTaskStatus)
+            
+    def filterDownloads(self, filter):
+        """
+        Filters the downloads list according to the user's chosen filter.
+        """
+        if filter is self.actionAll:
+            for row in range(self.listWidget.count()):
+                self.listWidget.setRowHidden(row, False)
+        elif filter is self.actionQueued:
+            for row in range(self.listWidget.count()):
+                task = youtubeservice.YouTubeVideoDownloader.taskQueue[row]
+                if task.getStatus() == "completed":
+                    self.listWidget.setRowHidden(row, True)
+                else:
+                    self.listWidget.setRowHidden(row, False)
+        else:
+            for row in range(self.listWidget.count()):
+                task = youtubeservice.YouTubeVideoDownloader.taskQueue[row]
+                if task.getStatus() == "completed":
+                    self.listWidget.setRowHidden(row, False)
+                else:
+                    self.listWidget.setRowHidden(row, True)
+        self.filterMenu(filter)
+        self.listWidget.setCurrentRow(-1)
+        
+    def filterMenu(self, filter):
+        """
+        Filters the available menu options.
+        """
+        if filter is self.actionAll:
+            for action in (self.actionPauseDownload, self.actionResumeDownload, self.actionRemoveFromQueue, self.actionResumeDownloads, self.actionPauseDownloads, self.actionClearQueue):
+                action.setVisible(True)
+        elif filter is self.actionQueued:
+            for action in (self.actionPauseDownload, self.actionResumeDownload, self.actionRemoveFromQueue, self.actionResumeDownloads, self.actionPauseDownloads):
+                action.setVisible(True)
+            self.actionClearQueue.setVisible(False)
+        else:
+            for action in (self.actionPauseDownload, self.actionResumeDownload, self.actionRemoveFromQueue, self.actionResumeDownloads, self.actionPauseDownloads, self.actionClearQueue):
+                action.setVisible(False)
+        
 
     def addVideo(self, videoData):
         size = QSize()
@@ -1301,12 +1326,12 @@ class DownloadsWindow(CutetubeWindows):
             try:
                 youtubeservice.YouTubeVideoDownloader.clearTasks()
                 self.listWidget.clear()
-                QMaemo5InformationBox.information(self, "Your download queue has been cleared")
+                QMaemo5InformationBox.information(self, "Your downloads have been cleared")
                 self.actionClearQueue.setVisible(False)
                 self.actionPlayQueue.setVisible(False)
                 self.emit(SIGNAL("downloadsChanged(int)"), 0)
             except:
-                QMaemo5InformationBox.information(self, "Unable to clear your download queue")
+                QMaemo5InformationBox.information(self, "Unable to clear your downloads")
             
     def cancelDownload(self):
         """
@@ -1316,7 +1341,8 @@ class DownloadsWindow(CutetubeWindows):
         row = self.listWidget.currentRow()
         youtubeservice.YouTubeVideoDownloader.cancelTask(row)
         task = youtubeservice.YouTubeVideoDownloader.taskQueue[row]
-        self.updateTaskStatus(task)
+        if task.getStatus() != "completed":
+            self.updateTaskStatus(task)
         self.listWidget.setCurrentRow(-1)
         
     def pauseDownload(self):
@@ -1327,7 +1353,8 @@ class DownloadsWindow(CutetubeWindows):
         row = self.listWidget.currentRow()
         youtubeservice.YouTubeVideoDownloader.pauseTask(row)
         task = youtubeservice.YouTubeVideoDownloader.taskQueue[row]
-        self.updateTaskStatus(task)
+        if task.getStatus() != "completed":
+            self.updateTaskStatus(task)
         self.listWidget.setCurrentRow(-1)
         
     def resumeDownload(self):
@@ -1337,7 +1364,8 @@ class DownloadsWindow(CutetubeWindows):
         row = self.listWidget.currentRow()
         youtubeservice.YouTubeVideoDownloader.resumeTask(row)
         task = youtubeservice.YouTubeVideoDownloader.taskQueue[row]
-        self.updateTaskStatus(task)
+        if task.getStatus() != "completed":
+            self.updateTaskStatus(task)
         self.listWidget.setCurrentRow(-1)
         
     @pyqtSignature("")
@@ -1348,7 +1376,8 @@ class DownloadsWindow(CutetubeWindows):
         for row in range(self.listWidget.count()):
             youtubeservice.YouTubeVideoDownloader.resumeTask(row)
             task = youtubeservice.YouTubeVideoDownloader.taskQueue[row]
-            self.updateTaskStatus(task)
+            if task.getStatus() != "completed":
+                self.updateTaskStatus(task)
             
     @pyqtSignature("")
     def on_actionPauseDownloads_triggered(self):
@@ -1358,7 +1387,8 @@ class DownloadsWindow(CutetubeWindows):
         for row in range(self.listWidget.count()):
             youtubeservice.YouTubeVideoDownloader.pauseTask(row)
             task = youtubeservice.YouTubeVideoDownloader.taskQueue[row]
-            self.updateTaskStatus(task)
+            if task.getStatus() != "completed":
+                self.updateTaskStatus(task)
 
     def updateDownloadStatus(self):
         """
@@ -1375,6 +1405,7 @@ class DownloadsWindow(CutetubeWindows):
                 if currentTask.progress  == 1.0:
                     QMaemo5InformationBox.information(self,  "Download of \'%s\' is completed" % unicode(currentTask.getTitle(), "utf-8"))
                     widget.speedLabel.setText("completed")
+                    self.filterDownloads(self.filterGroup.checkedAction())
             except AttributeError:
                 pass
             
