@@ -111,7 +111,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         youtubeservice.YouTubeDataService.userDict = settings.value("userDict",  {}).toPyObject()
         youtubeservice.YouTubeDataService.defaultUser = settings.value("defaultUser",  "").toString()
         youtubeservice.YouTubeDataService.raiseNoAccountFoundDialog = settings.value("noAccountDialog",  True).toBool()
-        youtubeservice.YouTubeVideoPlayer.mediaPlayer = settings.value("mediaPlayer",  "Media Player").toString()
+        youtubeservice.YouTubeVideoPlayer.mediaPlayer = settings.value("mediaPlayer",  "cuteTube Player").toString()
         youtubeservice.YouTubeVideoDownloader.downloadFolder = settings.value("downloadFolder",  "/home/user/MyDocs/.videos").toString()
         youtubeservice.YouTubeVideoDownloader.defaultTaskStatus = settings.value("downloadStatus",  "paused").toString()
         format = youtubeservice.YouTubeVideoPlayer.playbackFormat
