@@ -38,6 +38,8 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
             pass
         for button in (self.uploadsButton, self.favouritesButton, self.playlistsButton, self.subscriptionsButton):
             button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px;")
+            self.connect(button,  SIGNAL("pressed()"), self.changeButtonStyleSheet)
+            self.connect(button,  SIGNAL("released()"), self.changeButtonStyleSheet)
         self.keyPressEvent = self.showSearchDialog
         self.searchDialogRaised = False
         taskQueueLength = len(youtubeservice.YouTubeVideoDownloader.taskQueue)
@@ -48,6 +50,18 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
             self.actionSwitchAccount.setVisible(False)
         self.show()
         
+    def changeButtonStyleSheet(self):
+        """
+        Setting the QToolButton style sheets in the conventional 
+        way caused trouble with the Maemo specific widgets, so 
+        I'm using a signal instead.
+        """
+        button = self.sender()
+        if button.isDown():
+            button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px; background-color: rgb(120, 120, 120)")
+        else:
+            button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px;") 
+        
     def showSearchDialog(self,  event):
         """
         Raises a SearchDialog when the user presses a key.
