@@ -3,7 +3,6 @@
 """
 Module implementing VideoInfoWindow.
 """
-import os
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 import time
@@ -17,6 +16,7 @@ import cutetubedialogs
 import cutetubewindows
 import youtubeservice
 import customwidgets
+import videoplaybackwindow
 
 class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
     """
@@ -143,10 +143,12 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         videoTitle = self.video.title.text
         try:
-            self.ytPlayer = youtubeservice.YouTubeVideoPlayer(self, self.video)
-            self.ytPlayer.start()
-            #self.connect(self.ytPlayer, SIGNAL("playbackFinshed(bool)"), self.toggleBusy)
-            QMaemo5InformationBox.information(self, "Playing \'%s\'" % unicode(videoTitle, "utf-8"))
+            if youtubeservice.YouTubeVideoPlayer.mediaPlayer == "cuteTube Player":
+                videoPlaybackWindow = videoplaybackwindow.VideoPlaybackWindow(self, video = self.video)
+            else:
+                self.ytPlayer = youtubeservice.YouTubeVideoPlayer(self, self.video)
+                self.ytPlayer.start()
+                QMaemo5InformationBox.information(self, "Playing \'%s\'" % unicode(videoTitle, "utf-8"))
         except:
             QMaemo5InformationBox.information(self, "Unable to play video")
 
