@@ -18,6 +18,7 @@ import time
 import os
 import shutil
 import gdata.youtube.service
+import gdata.service
 
 class YouTubeDataService(object):
     """
@@ -213,9 +214,15 @@ class YouTubeVideoFeed(QThread):
         Retrieves and returns the video feed.
         """
         try:
-            self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
-        except:
-            self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
+            try:
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
+            except:
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
+        except gdata.service.RequestError:
+            try:
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
+            except:
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%s" % (self.videoFeed, unicode(self.results + 1))).encode("utf-8"))
             
     def getVideoData(self):
         for video in self.ytVideoFeed.entry:
@@ -351,7 +358,7 @@ class YouTubeVideoPlayer(QThread):
     """
     # Static variables
     playlist = []
-    mediaPlayer = "Media Player"
+    mediaPlayer = "cuteTube Player"
     formatList = ["17", "18", "34", "35", "22"]
     playbackFormat = "18"
     playCommandDict = {"KMPlayer": "dbus-send --print-reply --dest=com.nokia.kmplayer /com/nokia/kmplayer com.nokia.kmplayer.mime_open string:\'%s\'", "MPlayer": "mplayer -fs \'%s\'", "Media Player": "dbus-send --print-reply --dest=com.nokia.mediaplayer /com/nokia/mediaplayer com.nokia.mediaplayer.mime_open string:\'%s\'"}
@@ -374,7 +381,7 @@ class YouTubeVideoPlayer(QThread):
 
     def playYouTubeVideo(self):
         playbackCommand = YouTubeVideoPlayer.playCommandDict.get(unicode(YouTubeVideoPlayer.mediaPlayer))
-        filename = "%s/%s.mp4" % (YouTubeVideoDownloader.downloadFolder, re.sub('[<>:"/|?*\\\\]', "_", self.video.media.title.text).decode("utf-8"))
+        filename = "%s/%s.mp4" % (YouTubeVideoDownloader.downloadFolder, re.sub('[<>:"/|?*\\\\]', "-", self.video.media.title.text).decode("utf-8"))
         if os.path.exists(filename):
             os.system(playbackCommand % filename.encode("utf-8"))
         else:
@@ -393,6 +400,7 @@ class YouTubeVideoDownloader(object):
     downloadFormat = "18"
     downloadQueue = []
     taskQueue = []
+    completedDownloads = []
     currentTask = None
     currentStatus = "inactive"
     defaultTaskStatus = "queued"
@@ -439,6 +447,16 @@ class YouTubeVideoDownloader(object):
         if YouTubeVideoDownloader.currentStatus == "inactive":
             YouTubeVideoDownloader.run()
             
+    @staticmethod
+    def moveCompletedTask():
+        """
+        Moves the completed task to the completedDownloads list.
+        """
+        completedTask = YouTubeVideoDownloader.currentTask
+        YouTubeVideoDownloader.taskQueue.remove(completedTask)
+        YouTubeVideoDownloader.downloadQueue.remove(completedTask)
+        YouTubeVideoDownloader.completedDownloads.insert(0, completedTask)
+            
     @staticmethod
     def clearTasks():
         """
